rai\_toolbox.perturbations.uniform\_like\_linf\_n\_ball\_
=========================================================

.. currentmodule:: rai_toolbox.perturbations

.. autofunction:: uniform_like_linf_n_ball_